==> manna1-1.0.tar.gz: manna1-1.0/setup.py <==
from distutils.core import setup
setup(
  name = 'manna1',         # How you named your package folder (MyLib)
  packages = ['manna1'],   # Chose the same as "name"
  version = '1.0',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = ' A obfuscation technique to convert python code to bin files . Usage : from manna1 import *',   # Give a short description about your library
  author = 'Neelanjan Manna',                   # Type in your name
  author_email = 'igi.manna@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/neelanjanmanna2021',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/user/reponame/archive/v_01.tar.gz',    # I explain this later on
  keywords = ['steganography'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'validators',
          'beautifulsoup4',
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.11',
  ],
)

==> manna2-1.0.tar.gz: manna2-1.0/setup.py <==
from distutils.core import setup
setup(
  name = 'manna2',         # How you named your package folder (MyLib)
  packages = ['manna2'],   # Chose the same as "name"
  version = '1.0',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = ' An executor to launch encrypted bin files containing encrypted python code. Usage : from manna2 import *',   # Give a short description about your library
  author = 'Neelanjan Manna',                   # Type in your name
  author_email = 'igi.manna@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/neelanjanmanna2021',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/user/reponame/archive/v_01.tar.gz',    # I explain this later on
  keywords = ['steganography'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'validators',
          'beautifulsoup4',
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.11',
  ],
)
